/*
Murasaki - multiple genome global alignment program
Copyright (C) 2006-2007 Keio University
(Kris Popendorf) <comp@bio.keio.ac.jp> (2006)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef __MURASAKI_H
#define __MURASAKI_H

#include "sequence.h"
#include "options.h"

#define PROGRAMVERSION "1.03"

//these shoudl all be class-wrapped in some "options" class
extern int seq_count;
extern word usedBuckets,usedPats,worstPat;

extern Options opt;
extern Hash* mfh; //multi-fasta-hash (right now only support one instance)
extern string pattern_src;
extern vector<Sequence*> seqs;

void hashSeq(BitSequence *bitseq,BitSequence *pat,int sign,Sequence *s);
void procLocs(LocList &locList,list<Location> &use,int level=0);
string program_version();
bool hashSanityCheck();
string platformInfo();
word locList2mclass(LocList &locList);
ostream& outputRegions(ostream &of);
void hashStatusCheck(int tick,int pos);
void writeHisto(string hashHisto_record,string detailed);
void writeAnchors(string anchor_record);
bool convertPattern(string &pat);

extern int verbose; //debug mojo
extern word longestSeq,totalSeqLength,totalHashLength; //for eco-list parameter computation

class SystemInfo {
 public:
  unsigned long wordsize,totalMemory,freeMemory;
  int unit;

  SystemInfo();

  string toString() const;
  friend ostream& operator<<(ostream& of,const SystemInfo& a);
};

#endif
